@@ -17,7 +17,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street - Fifth Floor, Boston, MA  02110-1301, USA.
  *
- * $Id: albums.php 237 2008-07-27 13:30:18Z jens $
+ * $Id: albums.php 18010 2008-09-16 08:47:36Z JensT $
  */
 
 require_once(dirname(__FILE__) . '/init.php');
@@ -78,15 +78,15 @@ if ($gallery->session->albumListPage > $maxPages) {
 $pixelImage = '<img src="' . getImagePath('pixel_trans.gif') . '" width="1" height="1" alt="pixel_trans">';
 $borderColor = $gallery->app->default["bordercolor"];
 
-$navigator["page"] = $gallery->session->albumListPage;
-$navigator["pageVar"] = "set_albumListPage";
-$navigator["url"] = makeGalleryUrl("albums.php");
-$navigator["maxPages"] = $maxPages;
-$navigator["spread"] = 6;
-$navigator["fullWidth"] = 100;
-$navigator["widthUnits"] = "%";
-$navigator["bordercolor"] = $borderColor;
-$displayCommentLegend = 0;  // this determines if we display "* Item contains a comment" at end of page
+$navigator["page"]		= $gallery->session->albumListPage;
+$navigator["pageVar"]		= "set_albumListPage";
+$navigator["url"]		= makeGalleryUrl("albums.php");
+$navigator["maxPages"]		= $maxPages;
+$navigator["spread"]		= 6;
+$navigator["fullWidth"]		= 100;
+$navigator["widthUnits"]	= "%";
+$navigator["bordercolor"]	= $borderColor;
+$displayCommentLegend		= false;  // this determines if we display "* Item contains a comment" at end of page
 
 $currentUrl = makeGalleryUrl("albums.php", array("page" => $gallery->session->albumListPage));
 
@@ -214,7 +214,7 @@ if ($gallery->user->isLoggedIn() && !$gallery->session->offline) {
 if ($gallery->app->gallery_slideshow_type != "off" && $numPhotos != 0) {
 	$iconElements[] = galleryLink(
 		makeGalleryUrl("slideshow.php", array("set_albumName" => null)),
-		gTranslate('core', "Slideshow"), array(), 'presentation.gif'
+		gTranslate('core', "Slideshow"), array(), 'display.gif'
 	);
 }
 
@@ -255,7 +255,7 @@ $iconElements[] = LoginLogoutButton($currentUrl, $numPhotos, $currentUrl);
 if (!$loggedIn && !$GALLERY_EMBEDDED_INSIDE && $gallery->app->selfReg == 'yes') {
 	$iconElements[] = popup_link(
 		gTranslate('core', "Register"),
-		'register.php', false, true, 500, 500, '','','register.gif'
+		'register.php', false, true, 500, 500, '','', 'register.gif'
 	);
 }
 
@@ -288,7 +288,8 @@ if ( (sizeof($albumDB->brokenAlbums) || sizeof($albumDB->outOfDateAlbums)) && $g
 		foreach ($albumDB->brokenAlbums as $tmpAlbumName) {
 			echo "<br>$tmpAlbumName\n";
 		}
-	echo "\n</p>". gTranslate('core', "Please move it/them out of the albums directory.") ;
+
+		echo "\n</p>". gTranslate('core', "Please move it/them out of the albums directory.") ;
 	}
 
 	if(sizeof($albumDB->outOfDateAlbums)) {
@@ -296,7 +297,7 @@ if ( (sizeof($albumDB->brokenAlbums) || sizeof($albumDB->outOfDateAlbums)) && $g
 			Gallery(), sizeof($albumDB->outOfDateAlbums));
 
 		echo "\n<br>";
-		echo sprintf(gTranslate('core', "Please %s."), popup_link(gTranslate('core', "upgrade those albums"), "upgrade_album.php",0,0,500,500,"error"));
+		printf(gTranslate('core', "Please %s."), popup_link(gTranslate('core', "upgrade those albums"), "upgrade_album.php",0,0,500,500,"error"));
 	}
 	echo "\n</div></center>\n";
 }
@@ -305,8 +306,10 @@ if (getRequestVar('gRedir') == 1 && ! $gallery->session->gRedirDone) {
     echo "\n<center><div style=\"width:60%; border-style:outset; border-width:5px; border-color:red; padding: 5px\">";
     echo "\n<p class=\"head\"><u>". gTranslate('core', "Attention!") ."</u></p>";
 
-    echo sprintf(gTranslate('core', 'The album or photo that you were attempting to view either does not exist, or requires user privileges that you do not possess. %s'), ($gallery->user->isLoggedIn() && !$GALLERY_EMBEDDED_INSIDE ? '' : sprintf(gTranslate('core', "%s and try again."),
-    popup_link(gTranslate('core', "Log in"), "login.php", false, true, 500, 500))));
+    printf(gTranslate('core', 'The album or photo that you were attempting to view either does not exist, or requires user privileges that you do not possess. %s'),
+    	($gallery->user->isLoggedIn() && !$GALLERY_EMBEDDED_INSIDE ? '' : sprintf(gTranslate('core', "%s and try again."),
+	popup_link(gTranslate('core', "Log in"), "login.php", false, true, 500, 500)))
+    );
     echo "\n</div></center>\n";
     $gallery->session->gRedirDone = true;
 }
@@ -403,7 +406,14 @@ for ($i = $start; $i <= $end; $i++) {
     </table>
 
   <?php
-	include(dirname(__FILE__) . '/layout/adminAlbumCommands.inc');
+	echo "\n<div class=\"admin\">";
+  	$adminAlbumCommandsArray = getAlbumCommands($gallery->album, false, true);
+	if(!empty($adminAlbumCommandsArray)) {
+		foreach ($adminAlbumCommandsArray as $trash => $command ) {
+			echo $command['html'];
+		}
+	}
+	echo "</div>";
 
 	/*
 	* Description
@@ -491,12 +501,15 @@ for ($i = $start; $i <= $end; $i++) {
 					$clickCount,
 					sprintf(gTranslate('core', "This album has never been viewed since %s."), $resetDate)
 					),
-					$clickCount, $resetDate
-				);
+			$clickCount,
+			$resetDate
+		);
 	}
+
 	$albumName = $gallery->album->fields["name"];
 	if ($gallery->user->canWriteToAlbum($gallery->album) &&
-	(!($gallery->album->fields["display_clicks"] == "no"))) {
+	    (!($gallery->album->fields["display_clicks"] == "no")))
+	{
 		echo " ".popup_link(gTranslate('core', "reset counter"), doCommand("reset-album-clicks", array("set_albumName" => $albumName), "albums.php"), 1);
 	}
 
@@ -508,9 +521,10 @@ for ($i = $start; $i <= $end; $i++) {
 		switch ($gallery->app->comments_indication) {
 			case "albums":
 			case "both":
-			$lastCommentDate = $gallery->album->lastCommentDate($gallery->app->comments_indication_verbose);
-			print lastCommentString($lastCommentDate, $displayCommentLegend);
-		} // end switch
+				$lastCommentDate = $gallery->album->lastCommentDate($gallery->app->comments_indication_verbose);
+				print lastCommentString($lastCommentDate, $displayCommentLegend);
+			break;
+		}
 	}
 
 	echo "\n</span>";
@@ -552,9 +566,34 @@ if ($navigator["maxPages"] > 1) {
     includeLayout('navtablebegin.inc');
     includeLayout('navigator.inc');
     includeLayout('navtableend.inc');
-} else {
+}
+else {
     echo '<hr width="100%">';
 }
+
+if (!$gallery->session->offline) { ?>
+
+  <script language="javascript1.2" type="text/JavaScript">
+  <!-- //
+  var statusWin;
+  function showProgress() {
+  	statusWin = <?php echo popup_status("progress_uploading.php"); ?>
+  }
+
+  function hideProgress() {
+  	if (typeof(statusWin) != "undefined") {
+  		statusWin.close();
+  		statusWin = void(0);
+  	}
+  }
+
+  function hideProgressAndReload() {
+  	hideProgress();
+  	location.reload();
+  }
+  //-->
+  </script>
+<?php }
 ?>
 <p>
 <!-- gallery.footer begin -->
