@@ -17,7 +17,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street - Fifth Floor, Boston, MA  02110-1301, USA.
  *
- * $Id: Album.php 273 2008-08-03 17:36:37Z jens $
+ * $Id: Album.php 18010 2008-09-16 08:47:36Z JensT $
  */
 
 class Album {
@@ -28,10 +28,11 @@ class Album {
 	var $tsilb = "TSILB";
 
 	/*
-	* This variable contains data that is useful for the lifetime
-	* of the album object but which should not be saved in the
-	* database.  Data like the mirrorUrl which we want to validate
-	* the first time we touch an album.
+	 * transient
+	 * This variable contains data that is useful for the lifetime
+	 * of the album object but which should not be saved in the
+	 * database.  Data like the mirrorUrl which we want to validate
+	 * the first time we touch an album.
 	*/
 	var $transient;
 
@@ -281,13 +282,13 @@ class Album {
 		}
 
 		/* If the last album is a root album (= has no parent) and a returnto link is wanted,
-		 * add the link to Gallery mainpage
+		 *  add the link to Gallery mainpage
 		 */
 		if ($withGalleryLink && !isset($parentAlbum) && $currentAlbum->fields['returnto'] != 'no'){
 			$parentAlbumsArray[] = array(
-			'prefixText' => gTranslate('core', "Gallery"),
-			'title' => $gallery->app->galleryTitle,
-			'url' => makeGalleryUrl("albums.php"));
+				'prefixText'	=> gTranslate('core', "Gallery"),
+				'title'		=> clearGalleryTitle(),
+				'url'		=> makeGalleryUrl("albums.php"));
 		}
 
 		$parentAlbumsArray = array_reverse($parentAlbumsArray, true);
@@ -520,7 +521,7 @@ class Album {
 			}
 
 			if (isset($this->fields['print_photos']['shutterfly']) &&
-				!isset($this->fields['print_photos']['shutterfly']['checked'])) {
+			    !isset($this->fields['print_photos']['shutterfly']['checked'])) {
 				unset($this->fields['print_photos']['shutterfly']);
 			}
 		}
@@ -1029,10 +1030,10 @@ class Album {
 	}
 
 	/**
-     *  The parameter $msg should be an array ready to pass to sprintf.
-     * This is so we can translate into appropriate languages for each
-     * recipient.  You will note that we don't currently translate these messages.
-     */
+	 * The parameter $msg should be an array ready to pass to sprintf.
+	 * This is so we can translate into appropriate languages for each recipient.
+	 * You will note that we don't currently translate these messages.
+	 */
 	function save($msg = array(), $resetModDate = 1) {
 		global $gallery;
 		$dir = $this->getAlbumDir();
@@ -1124,10 +1125,10 @@ class Album {
 				$text .= "\n  <title>$subject</title>";
 				$text .= "\n  </head>\n<body>\n<p>";
 				$text .= sprintf(gTranslate('core', "A change has been made to album: %s by %s (IP %s).  The change is: %s"),
-				'<a href="'. makeAlbumHeaderUrl($this->fields['name']) .'">'. $this->fields['name'] .'</a>',
-				$gallery->user->printableName($gallery->app->comments_display_name),
-				$_SERVER['REMOTE_ADDR'],
-				$msg_str);
+						'<a href="'. makeAlbumHeaderUrl($this->fields['name']) .'">'. $this->fields['name'] .'</a>',
+						$gallery->user->printableName($gallery->app->comments_display_name),
+						$_SERVER['REMOTE_ADDR'],
+						$msg_str);
 
 				$text .= "\n<p>". gTranslate('core', "If you no longer wish to receive emails about this item, follow the links above and ensure that the 'other' checkbox in the 'Email me' box is unchecked. (You'll need to login first.)");
 				$text .= "\n</p>\n</body>\n</html>";
@@ -1219,9 +1220,9 @@ class Album {
 	 * Resize and optionally shrink all photos of an album. Movies are skipped.
 	 * If wanted this can be done recursive.
 	 *
-	 * @param integer	$target		New size of the longest site in pixel.
-	 * @param integer	$filesize	New minimum filesize.
-	 * @param boolean	$recursive	True if you want to resize elements in subalbums, too.
+	 * @param integer  $target      New size of the longest site in pixel.
+	 * @param integer  $filesize    New minimum filesize.
+	 * @param boolean  $recursive   True if you want to resize elements in subalbums, too.
 	 */
 	function resizeAllPhotos($target, $filesize = 0, $recursive = false) {
 		$numItems = $this->numPhotos(1);
@@ -1237,7 +1238,7 @@ class Album {
 		echo addProgressbar(
 			$progressbarID,
 			sprintf(
-				gTranslate('core', "Resizing items in album: '<i>%s</i>' (%s)' with %d items"),
+				gTranslate('core', "Resizing items in album: '<i>%s</i>' (%s) with %d items."),
 				$this->fields['title'],
 				$this->fields['name'],
 				$numItems)
@@ -1355,7 +1356,7 @@ class Album {
 		echo debugMessage("&nbsp;&nbsp;&nbsp;". gTranslate('core', "Resizing/compressing original file"), __FILE__, __LINE__,1);
 
 		if (isImage($tag)) {
-			resize_image($newFile, $newFile, $this->fields['max_size'], $this->fields['max_file_size'], true, false);
+			$resize_status = resize_image($newFile, $newFile, $this->fields['max_size'], $this->fields['max_file_size'], true, false);
 		}
 		elseif (isMovie($tag)) {
 			processingMsg(gTranslate('core', "File is a movie, no resizing done."));
@@ -1364,6 +1365,14 @@ class Album {
 			processingMsg(sprintf(gTranslate('core', "Invalid filetype: %s. Skipping."), $tag));
 		}
 
+		if($resize_status == 10) {
+			$errorMsg = ($plainErrorMessage) ?
+					gTranslate('core', "Item looks like an image, but has no dimensions? Please verify it's not a broken image.") :
+					gallery_error(gTranslate('core', "Item looks like an image, but has no dimensions? Please verify it's not a broken image."));
+
+			return array(false, $errorMsg);
+		}
+
 		/* Create an albumitem */
 		$item = new AlbumItem();
 		$status = $item->setPhoto($dir, $name, $tag, $this->fields['thumb_size'], $this, $pathToThumb);
@@ -1373,15 +1382,9 @@ class Album {
 				fs_unlink($newFile);
 			}
 
-			if($plainErrorMessage) {
-				$errorMsg = gTranslate('core', "Item not added.");
-			}
-			else {
-				$errorMsg = infobox(array(array(
-						'type' => 'error',
-						'text' => gTranslate('core', "Item not added.")
-				)));
-			}
+			$errorMsg = ($plainErrorMessage) ?
+					gTranslate('core', "Item not added.") :
+					gallery_error(gTranslate('core', "Item not added."));
 
 			return array($status, $errorMsg);
 		}
@@ -1624,6 +1627,7 @@ class Album {
 		if ( ($photo[0]->isHighlight()) && ($this->numPhotos(1) > 0) && (!$forceResetHighlight==-1)) {
 			$needToRehighlight = 1;
 		}
+
 		$photo[0]->delete($this->getAlbumDir());
 		if (($needToRehighlight) || ($forceResetHighlight==1)){
 			// Prevent hidden items, albums, and movies from
@@ -1636,6 +1640,8 @@ class Album {
 				}
 			}
 		}
+
+		return true;
 	}
 
 	function newPhotoName() {
@@ -1669,20 +1675,23 @@ class Album {
 	 * @return string
 	 */
 	function getThumbnailTag($index, $size = 0, $attrs = array()) {
+		static $usedIDs = array();
+
 		if ($index === null) {
 			return '';
 		}
 
-		if(empty($attrs['id'])) {
-			$attrs['id'] = "thumbnail_${index}";
-		}
-
 		$photo = $this->getPhoto($index);
 
 		if(! $photo) {
 			return '';
 		}
 
+		if(empty($attrs['id']) && ! in_array($index, $usedIDs)) {
+			$attrs['id'] = "thumbnail_${index}";
+			$usedIDs[] = $index;
+		}
+
 		if ($photo->isAlbum()) {
 			$myAlbum = $this->getNestedAlbum($index);
 			return $myAlbum->getHighlightAsThumbnailTag($size, $attrs);
@@ -1768,8 +1777,8 @@ class Album {
 
 			if(isset($attrList['class'])) {
 				$attrList['class'] .= ' title';
-		}
-		else {
+			}
+			else {
 				$attrList['class'] = 'title';
 			}
 
@@ -1943,7 +1952,7 @@ class Album {
 		return (array($numItemsTotal, $numAlbums, $numPhotos));
 	}
 
-	function numVisibleItems($user, $returnVisibleItems=false) {
+	function numVisibleItems($user, $returnVisibleItems = false) {
 		$uuid = $user->getUid();
 
 		if ($returnVisibleItems) {
@@ -1975,12 +1984,13 @@ class Album {
 
 		if ($returnVisibleItems) {
 			return array($numPhotos, $numAlbums, $visibleItems);
-		} else {
+		}
+		else {
 			return array($numPhotos, $numAlbums);
 		}
 	}
 
-	function getIds($show_hidden = 0) {
+	function getIds($show_hidden = false) {
 		foreach ($this->photos as $photo) {
 			if ((!$photo->isHidden() || $show_hidden) && !$photo->getAlbumName()) {
 				$ids[] = $photo->getPhotoId();
@@ -2193,6 +2203,7 @@ class Album {
 
 	function getComment($photoIndex, $commentIndex) {
 		$photo = $this->getPhoto($photoIndex);
+
 		return $photo->getComment($commentIndex);
 	}
 
@@ -2309,7 +2320,7 @@ class Album {
 		echo addProgressbar(
 				$progressbarID,
 				sprintf(
-					gTranslate('core', "Updating album: '<i>%s</i>' (%s)' with %d items"),
+					gTranslate('core', "Updating album: '<i>%s</i>' (%s) with %d items."),
 					$this->fields['title'],
 					$this->fields['name'],
 					$numItems)
@@ -2322,7 +2333,7 @@ class Album {
 				$np = $nestedAlbum->numPhotos(1);
 
 				echo "<br>";
-				printf(gTranslate('core', "Entering subalbum '<i>%s</i>', processing %d items"), $this->getAlbumName($i), $np);
+				printf(gTranslate('core', "Entering subalbum '<i>%s</i>', processing %d items."), $this->getAlbumName($i), $np);
 				$nestedAlbum->makeThumbnails($recursive);
 				$nestedAlbum->save();
 			}
@@ -2403,22 +2414,21 @@ class Album {
 	function isItemOwner($uid, $index) {
 		global $gallery;
 
-		if($uid == $this->getItemOwner($index)) {
+		$ownerID = $this->getItemOwner($index);
+
+		if($uid == $ownerID) {
+			debugMessage(sprintf(gTranslate('core', "Userid %s is owner of '%s'"), $uid, $this->fields['name']), __FILE__, __LINE__);
 			return true;
 		}
 
 		$everybody	= $gallery->userDB->getEverybody();
 		$everybodyUid	= $everybody->getUid();
-		if($this->getItemOwner($index) == $everybodyUid) {
-			return true;
-		}
-
-		$nobody		= $gallery->userDB->getNobody();
-		$nobodyUid	= $nobody->getUid();
-		if ($uid == $nobodyUid) {
+		if($ownerID == $everybodyUid) {
+			debugMessage(sprintf(gTranslate('core', "Userid %s is owner of '%s'"), $uid, $this->fields['name']), __FILE__, __LINE__);
 			return true;
 		}
 
+		debugMessage(sprintf(gTranslate('core', "Userid %s is NOT owner of '%s'"), $uid, $this->fields['name']), __FILE__, __LINE__);
 		return false;
 	}
 
@@ -2600,6 +2610,10 @@ class Album {
 		return strftime($gallery->app->dateString,$time);
 	}
 
+	/**
+	 * @Todo: Sync with edit_appearance. Don't wanna touch both everytime.
+	 *
+	 */
 	function setNestedProperties() {
 		for ($i=1; $i <= $this->numPhotos(1); $i++) {
 			if ($this->isAlbum($i)) {
@@ -2708,7 +2722,22 @@ class Album {
 		}
 	}
 
+	/**
+	 * Get a dedicated permission for a user.
+	 * Note: Added in 1.5.9 that admins are always permitted to do something.
+	*/
 	function getPerm($permName, $uid) {
+		global $gallery;
+		static $user;
+
+		if(empty($user)) {
+			$user = $gallery->userDB->getUserByUid($uid);
+		}
+
+		if ($user->isAdmin()) {
+			return true;
+		}
+
 		if (isset($this->fields['perms'][$permName])) {
 			$perm = $this->fields['perms'][$permName];
 		}
@@ -2720,7 +2749,6 @@ class Album {
 			return true;
 		}
 
-		global $gallery;
 
 		/* If everybody has the perm, then we do too */
 		$everybody = $gallery->userDB->getEverybody();
@@ -2792,67 +2820,27 @@ class Album {
 		}
 	}
 
-	// -------------
-	function canRead($uid) {
+	/**
+	 * Is a user allowed to add comments?
+	 * Owner (and admins) are always allowed.
+	 *
+	 * @param string   $uid
+	 * @return boolean
+	 */
+	function canAddComments($uid) {
 		if ($this->isOwner($uid)) {
 			return true;
 		}
-
-		// In the default case where there are no permissions for the album,
-		// let everybody see it.
-		if (!isset($this->fields['perms'])) {
-			return 1;
-		}
-
-		return $this->getPerm("canRead", $uid);
+		return $this->getPerm("canAddComments", $uid);
 	}
 
-	function canReadRecurse($uid) {
-		global $albumDB;
-		if (empty($albumDB)) {
-			$albumDB = new AlbumDB();
-		}
-
-		if ($this->isOwner($uid)) {
-			return true;
-		}
-		elseif ($this->canRead($uid)) {
-			if ($this->isRoot() || empty($this->fields['parentAlbumName'])) {
-				return true;
-			}
-			$parent = $albumDB->getAlbumByName($this->fields['parentAlbumName'], false);
-			return $parent->canReadRecurse($uid);
-		}
-		else {
-			return false;
-		}
-	}
-
-	// -------------
-	function canWrite($uid) {
-		if ($this->isOwner($uid)) {
-			return true;
-		}
-		return $this->getPerm("canWrite", $uid);
-	}
-
-	// -------------
-	function canDelete($uid) {
-		if ($this->isOwner($uid)) {
-			return true;
-		}
-		return $this->getPerm("canDelete", $uid);
-	}
-
-	// -------------
-	function canDeleteFrom($uid) {
-		if ($this->isOwner($uid)) {
-			return true;
-		}
-		return $this->getPerm("canDeleteFrom", $uid);
-	}
-
-	// -------------
+	/**
+	 * Is a user allowed to add items to the album?
+	 * Owner (and admins) are always allowed.
+	 *
+	 * @param string   $uid
+	 * @return boolean
+	 */
 	function canAddTo($uid) {
 		if ($this->isOwner($uid)) {
 			return true;
@@ -2860,7 +2848,13 @@ class Album {
 		return $this->getPerm("canAddTo", $uid);
 	}
 
-	// -------------
+	/**
+	 * Is a user allowed to change album texts?
+	 * Owner (and admins) are always allowed.
+	 *
+	 * @param string   $uid
+	 * @return boolean
+	 */
 	function canChangeText($uid) {
 		if ($this->isOwner($uid)) {
 			return true;
@@ -2868,7 +2862,13 @@ class Album {
 		return $this->getPerm("canChangeText", $uid);
 	}
 
-	// -------------
+	/**
+	 * Is a user allowed to create subalbums?
+	 * Owner (and admins) are always allowed.
+	 *
+	 * @param string   $uid
+	 * @return boolean
+	 */
 	function canCreateSubAlbum($uid) {
 		if ($this->isOwner($uid)) {
 			return true;
@@ -2876,7 +2876,109 @@ class Album {
 		return $this->getPerm("canCreateSubAlbum", $uid);
 	}
 
-	// -------------
+	/**
+	 * Is a user allowed to delete an album?
+	 * Owner (and admins) are always allowed.
+	 *
+	 * @param string   $uid
+	 * @return boolean
+	 */
+	function canDelete($uid) {
+		if ($this->isOwner($uid)) {
+			return true;
+		}
+
+		return $this->getPerm("canDelete", $uid);
+	}
+
+	/**
+	 * Is a user allowed to delete items from an album?
+	 * Owner (and admins) are always allowed.
+	 *
+	 * @param string   $uid
+	 * @return boolean
+	 */
+	function canDeleteFrom($uid) {
+		if ($this->isOwner($uid)) {
+			return true;
+		}
+
+		return $this->getPerm("canDeleteFrom", $uid);
+	}
+
+	/**
+	 * Who can see the album?
+	 * Owner (and admins) are always allowed.
+	 * NOTE: Added in 1.5.9 that admins are always allowed.
+	 *       REMOVED that everybody can see an album if no permissions are set.
+	 *
+	 *
+	 * @param string   $uid
+	 * @return boolean
+	 */
+	function canRead($uid) {
+		if ($this->isOwner($uid)) {
+			return true;
+		}
+
+		if (!isset($this->fields['perms'])) {
+			return true;
+		}
+
+		return $this->getPerm("canRead", $uid);
+	}
+
+
+	/**
+	 * Would a user be possible to see this album from root down?
+	 * Recursive call of 'canRead'
+	 *
+	 * @param string   $uid
+	 * @return boolean
+	 */
+	function canReadRecurse($uid) {
+		global $albumDB;
+
+		if (empty($albumDB)) {
+			$albumDB = new AlbumDB();
+		}
+
+		if ($this->canRead($uid)) {
+			if ($this->isRoot() || empty($this->fields['parentAlbumName'])) {
+				return true;
+			}
+
+			$parent = $albumDB->getAlbumByName($this->fields['parentAlbumName'], false);
+
+			return $parent->canReadRecurse($uid);
+		}
+		else {
+			return false;
+		}
+	}
+
+	/**
+	 * Is a user allowed to view comments?
+	 * Owner (and admins) are always allowed.
+	 *
+	 * @param string   $uid
+	 * @return boolean
+	 */
+	function canViewComments($uid) {
+		if ($this->isOwner($uid)) {
+			return true;
+		}
+
+		return $this->getPerm("canViewComments", $uid);
+	}
+
+	/**
+	 * Who can see the full/original images?
+	 * Owner (and admins) are always allowed.
+	 *
+	 * @param string   $uid
+	 * @return boolean
+	 */
 	function canViewFullImages($uid) {
 		if ($this->isOwner($uid)) {
 			return true;
@@ -2927,26 +3029,35 @@ class Album {
 		return false;
 	}
 
-	// -------------
-	function canAddComments($uid) {
+	/**
+	 * Can a user modify items in his/her album?
+	 * Rotate, Resize, Watermark, Reorder
+	 * But not: Delete or Move!
+	 * Owner (and admins) are always allowed.
+	 *
+	 * @param string    $uid
+	 * @return boolean
+	 */
+	function canWrite($uid) {
 		if ($this->isOwner($uid)) {
 			return true;
 		}
-		return $this->getPerm("canAddComments", $uid);
+		return $this->getPerm("canWrite", $uid);
 	}
 
-	// -------------
-	function canViewComments($uid) {
-		if ($this->isOwner($uid)) {
-			return true;
-		}
-		return $this->getPerm("canViewComments", $uid);
-	}
-
-	// -------------
+	/**
+	 * Is a user owner of an album?
+	 * Also special users like nobody, everbody or loggedIn can be the owner!
+	 * An admin does not own every album!
+	 *
+	 * @param string   $uid
+	 * @return boolean
+	 */
 	function isOwner($uid) {
 		global $gallery;
 
+		//debugMessage(sprintf(gTranslate('core',"OwnerUID of album '%s' is '%s' || Tested uid is '%s'"), $this->fields['name'], $this->fields['owner'], $uid), __FILE__, __LINE__);
+
 		if(!isset($this->fields['owner'])) {
 			return false;
 		}
@@ -2957,10 +3068,18 @@ class Album {
 
 		$everybody	= $gallery->userDB->getEverybody();
 		$everybodyUid	= $everybody->getUid();
+
 		if($this->fields['owner'] == $everybodyUid) {
 			return true;
 		}
 
+		$loggedIn	= new LoggedinUser();
+		$loggedInUid	= $loggedIn->getUid();
+
+		if($this->fields['owner'] == $loggedInUid && $gallery->user->isLoggedIn()) {
+			return true;
+		}
+
 		return false;
 	}
 
@@ -3131,7 +3250,7 @@ class Album {
 			return '';
 		}
 
-	return '('. showOwner($owner) .')';
+		return '('. showOwner($owner) .')';
 	}
 
 	/**
@@ -3241,7 +3360,9 @@ class Album {
 			return false;
 		}
 		for ($i = 0; $i<$this->fields['poll_scale']; $i++ ) {
-			if ($this->fields['poll_nv_pairs'][$i]['value'] != $album->fields['poll_nv_pairs'][$i]['value'] ) {
+			if ($this->fields['poll_nv_pairs'][$i]['value'] !=
+			    $album->fields['poll_nv_pairs'][$i]['value'] )
+			{
 				return false;
 			}
 		}
@@ -3505,10 +3626,16 @@ class Album {
 	}
 
 	/**
-     *
-    */
+	 * Returns the size of an album in Bytes.
+	 * If a user s given, only his/her elements are counted.
+	 *
+	 * @param object   $user
+	 * @param boolean  $full
+	 * @param boolean  $visibleOnly
+	 * @param boolean  $recursive
+	 * @return integer albumSize
+	 */
 	function getAlbumSize($user = NULL, $full = false, $visibleOnly = false, $recursive = false) {
-
 		$albumSize = 0;
 		$albumItemNames = $this->getAlbumItemNames($user, $full, $visibleOnly, $recursive);
 		$justPureFileNames = array_flaten($albumItemNames);
