@@ -17,7 +17,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street - Fifth Floor, Boston, MA  02110-1301, USA.
  *
- * $Id: album.php 234 2008-07-27 12:04:14Z jens $
+ * $Id: album.php 17982 2008-09-09 21:24:10Z JensT $
  */
 
 /**
@@ -170,7 +170,7 @@ function getParentAlbums($childAlbum, $addChild = false) {
 	$pAlbum = $childAlbum;
 	$parentNameArray = array();
 
-	if ($addChild == true) {
+	if ($addChild) {
 		$parentNameArray[$pAlbum->fields['name']] = $pAlbum->fields['title'];
 	}
 
@@ -183,6 +183,36 @@ function getParentAlbums($childAlbum, $addChild = false) {
 	return $parentNameArray;
 }
 
+/**
+ * This function returns the CSS for the settings a user did in the album appearance
+ *
+ */
+function customCSS() {
+	global $gallery;
+
+	$customCSS = '';
+
+	// the link colors have to be done here to override the style sheet
+	if ($gallery->album->fields["linkcolor"]) {
+		$customCSS .= "  a:link, a:visited, a:active { color: ".$gallery->album->fields['linkcolor'] ."; }\n";
+		$customCSS .= "  a:hover { color: #ff6600; }\n";
+	}
+
+	if ($gallery->album->fields["bgcolor"]) {
+		$customCSS .= "  body { background-color:".$gallery->album->fields['bgcolor']."; }\n";
+	}
+
+	if (isset($gallery->album->fields['background']) && $gallery->album->fields['background']) {
+		$customCSS .= "  body { background-image:url(".$gallery->album->fields['background']."); }\n";
+	}
+
+	if ($gallery->album->fields["textcolor"]) {
+		$customCSS .= "  body, tf { color:".$gallery->album->fields['textcolor']."; } \n";
+	}
+
+	return $customCSS;
+}
+
 /**
  * returns the a HTML string containg links to the upper albums
  *
@@ -211,7 +241,10 @@ function returnToPathArray($album = NULL, $withCurrentAlbum = true, $photoview =
 				$i++;
 				$link = $navAlbum['prefixText'] .': ';
 				if($i == $numParents) {
-					$link .= galleryLink($navAlbum['url'], $navAlbum['title'] ."&nbsp;$lastUpArrow");
+					$link .= galleryLink(
+							$navAlbum['url'],
+							$navAlbum['title'] ."&nbsp;$lastUpArrow"
+					);
 				}
 				else {
 					$link .= galleryLink($navAlbum['url'], $navAlbum['title'] ."&nbsp;$upArrow",
@@ -222,8 +255,9 @@ function returnToPathArray($album = NULL, $withCurrentAlbum = true, $photoview =
 		}
 		elseif ($photoview) {
 			$pathArray[] = galleryLink(
-						makeAlbumUrl($gallery->album->fields['name']),
-						$gallery->album->fields['title'] ."&nbsp;$lastUpArrow");
+					makeAlbumUrl($gallery->album->fields['name']),
+					$gallery->album->fields['title'] ."&nbsp;$lastUpArrow"
+			);
 		}
 	}
 	else {
@@ -238,6 +272,120 @@ function returnToPathArray($album = NULL, $withCurrentAlbum = true, $photoview =
 	return $pathArray;
 }
 
+/**
+ * Test Suite for albums
+ *
+ * @param string $test
+ * @return boolean
+ * @author Beckett Madden-Woods
+ */
+function testRequirement($test) {
+	global $gallery;
+
+	if(substr($test, 0,1 ) == "!") {
+		$test = substr($test, 1);
+		$negativeTest = true;
+	}
+	else {
+		$negativeTest = false;
+	}
+
+	switch ($test) {
+		case 'albumIsRoot':
+			$result = $gallery->album->isRoot();
+		break;
+
+		case 'isAdminOrAlbumOwner':
+			$result = $gallery->user->isAdmin() || $gallery->user->isOwnerOfAlbum($gallery->album);
+		break;
+
+		case 'comments_enabled':
+			$result = $gallery->app->comments_enabled == 'yes';
+		break;
+
+		case 'allowComments':
+			$result = $gallery->album->fields["perms"]['canAddComments'];
+		break;
+
+		case 'hasComments':
+			$result = ($gallery->album->lastCommentDate("no") != -1);
+		break;
+
+		case 'comments_overview_for_all':
+			if($gallery->user->isAdmin() || $gallery->user->isOwnerOfAlbum($gallery->album) ||
+			   (isset($gallery->app->comments_overview_for_all) &&
+			    $gallery->app->comments_overview_for_all == 'yes' &&
+			    $gallery->user->canViewComments($gallery->album)
+			   ))
+			{
+				$result = true;
+			}
+			else {
+				$result = false;
+			}
+		break;
+
+		case 'canAddToAlbum':
+			$result = $gallery->user->canAddToAlbum($gallery->album);
+		break;
+
+		case 'canDeleteAlbum':
+			$result = $gallery->user->canDeleteAlbum($gallery->album);
+		break;
+
+		case 'extraFieldsExist':
+			$extraFields = $gallery->album->getExtraFields();
+			$result = !empty($extraFields);
+		break;
+
+		case 'isAlbumOwner':
+			$result = $gallery->user->isOwnerOfAlbum($gallery->album);
+		break;
+
+		case 'canCreateSubAlbum':
+			$result = $gallery->user->canCreateSubAlbum($gallery->album);
+		break;
+
+		case 'notOffline':
+			$result = !$gallery->session->offline;
+		break;
+
+		case 'canChangeText':
+			$result = $gallery->user->canChangeTextOfAlbum($gallery->album);
+		break;
+
+		case 'canWriteToAlbum':
+			$result = $gallery->user->canWriteToAlbum($gallery->album);
+		break;
+
+		case 'photosExist':
+			$result = $gallery->album->numPhotos(true);
+		break;
+
+		case 'watermarkingEnabled':
+			$result = isset($gallery->app->watermarkDir);
+		break;
+
+		case 'exif':
+			$result = (getExifDisplayTool() !== false);
+		break;
+
+		case 'votingOn':
+			$result = ($gallery->album->getVoterClass()) != 'Nobody';
+		break;
+
+		default:
+			$result = false;
+		break;
+	}
+
+	if ($negativeTest) {
+		$result = ! $result;
+	}
+
+	return $result;
+}
+
 /**
  * Checks whether a requirement is set.
  *
@@ -311,7 +459,7 @@ function getAlbumCommands($album, $caption = false, $mainpage = true) {
 	if (checkRequirements('canChangeText')) {
 		$albumCommands[] = array(
 			'class'	=> 'url',
-			'text'	=> gTranslate('common',"Edit captions"),
+			'text'	=> gTranslate('common', "Edit captions"),
 			'html'	=> galleryLink(
 					makeGalleryUrl(
 						'captionator.php',
@@ -337,7 +485,7 @@ function getAlbumCommands($album, $caption = false, $mainpage = true) {
 
 		/* User is allowed to change album permissions */
 		$albumCommands[] = array(
-			'text'	=> gTranslate('common',"Permissions"),
+			'text'	=> gTranslate('common', "Permissions"),
 			'html'	=> popup_link(gTranslate('common',"Permissions"),
 						"album_permissions.php?set_albumName={$albumName}",
 						0, true,
@@ -347,7 +495,7 @@ function getAlbumCommands($album, $caption = false, $mainpage = true) {
 
 		/* And to change album properties */
 		$albumCommands[] = array(
-			'text'	=> gTranslate('common',"Properties"),
+			'text'	=> gTranslate('common', "Properties"),
 			'html'	=> popup_link(gTranslate('common',"Properties"),
 						"edit_appearance.php?set_albumName={$albumName}",
 						0, true,
@@ -359,7 +507,7 @@ function getAlbumCommands($album, $caption = false, $mainpage = true) {
 		/* Watermarking support is enabled and user is allowed to watermark images/albums */
 		if (checkRequirements('photosExist','watermarkingEnabled')) {
 			$albumCommands[] = array(
-				'text'	=> gTranslate('common',"Watermark&nbsp;album"),
+				'text'	=> gTranslate('common', "Watermark&nbsp;album"),
 				'html'	=> popup_link(gTranslate('common',"Watermark&nbsp;album"),
 							"watermark_album.php?set_albumName=$albumName"),
 				'value'	=> build_popup_url("watermark_album.php?set_albumName=$albumName")
@@ -373,19 +521,36 @@ function getAlbumCommands($album, $caption = false, $mainpage = true) {
 		/* User is allowed to delete the album */
 		if (checkRequirements('canDeleteAlbum')) {
 			$albumCommands[] = array(
-				'text'	=> gTranslate('common',"Delete album"),
+				'text'	=> gTranslate('common', "Delete album"),
 				'html'	=> popup_link(gTranslate('common',"Delete album"),
 							"delete_album.php?set_albumName=$albumName"),
 				'value'	=> build_popup_url("delete_album.php?set_albumName=$albumName")
 			);
 		}
+
+		/* User is allowed to change the album */
+		if (checkRequirements('canWriteToAlbum')) {
+			$albumCommands[] = array(
+				'text'	=> gTranslate('common', "Move album"),
+				'html'	=> popup_link(gTranslate('common',"Move album"),
+							"move_album.php?set_albumName={$albumName}&index=$i&reorder=0"),
+				'value'	=> build_popup_url("move_album.php?set_albumName={$albumName}&index=$i&reorder=0")
+			);
+
+			$albumCommands[] = array(
+				'text'	=> gTranslate('common', "Reorder album"),
+				'html'	=> popup_link(gTranslate('common',"Reorder album"),
+							"move_album.php?set_albumName={$albumName}&index=$i&reorder=1"),
+				'value'	=> build_popup_url("move_album.php?set_albumName={$albumName}&index=$i&reorder=1")
+			);
+		}
 	}
 	/* Options that are only shown for subalbums */
 	else {
 		/* User is allowed to delete the subalbum */
 		if (checkRequirements('canDeleteAlbum')) {
 			$albumCommands[] = array(
-				'text'	=> gTranslate('common',"Delete this (sub)album"),
+				'text'	=> gTranslate('common', "Delete this (sub)album"),
 				'html'	=> popup_link2(
 							gTranslate('common', "Delete this (sub)album"),
 							makeGalleryUrl('delete_item.php',
@@ -393,8 +558,8 @@ function getAlbumCommands($album, $caption = false, $mainpage = true) {
 									'set_albumName'	=> $album->fields['parentAlbumName'],
 									'index' => $i,
 									'id' => $id,
-									'gallery_popup' => true)),
-							array('accesskey' => true)),
+									'gallery_popup' => true))
+								),
 				'value'	=> build_popup_url(makeGalleryUrl('delete_item.php',
 								array(
 									'set_albumName' => $album->fields['parentAlbumName'],
@@ -406,7 +571,6 @@ function getAlbumCommands($album, $caption = false, $mainpage = true) {
 		}
 	}
 
-
 	/* Options shown only in thumbsview */
 	if(!$mainpage) {
 		if (checkRequirements('canWriteToAlbum', 'photosExist')) {
@@ -417,7 +581,6 @@ function getAlbumCommands($album, $caption = false, $mainpage = true) {
 				'value'	=> build_popup_url("sort_album.php?set_albumName=$albumName")
 			);
 
-
 			$albumCommands[] = array(
 				'text'	=> gTranslate('common', "Resize all"),
 				'html'	=> popup_link(gTranslate('common',"Resize all"),
@@ -473,7 +636,7 @@ function getAlbumCommands($album, $caption = false, $mainpage = true) {
 	/* Options shown only on the mainpage */
 	else {
 		/* User is allowed to view ALL comments */
-		if (checkRequirements('isAdminOrAlbumOwner', 'allowComments', 'comments_enabled', 'hasComments')) {
+		if (checkRequirements('comments_enabled', 'hasComments', 'comments_overview_for_all')) {
 			$albumCommands[] = array(
 				'class'	=> 'url',
 				'text'	=> gTranslate('common',"View&nbsp;comments"),
@@ -497,4 +660,27 @@ function getAlbumCommands($album, $caption = false, $mainpage = true) {
 
 	return $albumCommands;
 }
+
+/**
+ * returns the a HTML string that shows a breadcrumb to an album
+ *
+ * @param array    $parents
+ * @return string  $html
+ * @author Jens Tkotz
+ */
+function albumBreadcrumb($parents) {
+	$html = '';
+
+	$nr = 0;
+	foreach ($parents as $album) {
+		$html .= $album['title'];
+		$nr ++;
+		if($nr < sizeof($parents)) {
+			$html .= ' >> ';
+		}
+	}
+
+	return $html;
+}
+
 ?>
\ No newline at end of file
