@@ -17,7 +17,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street - Fifth Floor, Boston, MA  02110-1301, USA.
  *
- * $Id: albumItem.php 253 2008-07-28 19:08:00Z jens $
+ * $Id: albumItem.php 18002 2008-09-15 23:31:05Z JensT $
  */
 
 /**
@@ -316,7 +316,7 @@ function getItemActions($i, $withIcons = false, $popupsOnly = false, $caption =
 	array_sort_by_fields($options, 'text');
 
 	if(!empty($options) && $caption) {
-		array_unshift($options,array(
+		array_unshift($options, array(
 					'text'		=> '&laquo; '. sprintf(gTranslate('core', "%s actions"), $label) . ' &raquo;',
 					'selected'	=> true
 		));
@@ -352,51 +352,55 @@ function showComments ($index, $albumName, $reverse = false) {
 		'class' => 'commentbox')
 	);
 
-    $columns = ($gallery->user->canWriteToAlbum($gallery->album)) ? 4 : 3;
-    $commentTable->setColumnCount($columns);
+	$columns = ($gallery->user->canWriteToAlbum($gallery->album)) ? 4 : 3;
+	$commentTable->setColumnCount($columns);
 
-    for ($nr =1; $nr <= $numComments; $nr++) {
-        $comment = $gallery->album->getComment($index, $nr);
+	for ($nr =1; $nr <= $numComments; $nr++) {
+		$comment = $gallery->album->getComment($index, $nr);
 
-        $commenterName = '<b>'. wordwrap($comment->getName(), 50, " ", 1) .'</b>';
-        if ($gallery->user->isAdmin()) {
-            $commenterName .= '@ &nbsp;'. $comment->getIPNumber();
-        }
+		$commenterName = '<b>'. wordwrap($comment->getName(), 50, " ", 1) .'</b>';
+		if ($gallery->user->isAdmin()) {
+			$commenterName .= '@ &nbsp;'. $comment->getIPNumber();
+		}
 
-        $commentTable->addElement(array(
-            'content' => gTranslate('core', "From:"),
-            'cellArgs' => array('class' => 'admin', 'width' => 50, 'height' => '25')));
+		$commentTable->addElement(array(
+			'content'	=> gTranslate('core', "From:"),
+			'cellArgs'	=> array('class' => 'admin', 'width' => 50, 'height' => '25')));
 
-        $commentTable->addElement(array(
-            'content' => $commenterName,
-            'cellArgs' => array('class' => 'admin', 'width' => '55%')));
+		$commentTable->addElement(array(
+			'content'	=> $commenterName,
+			'cellArgs'	=> array('class' => 'admin', 'width' => '55%')));
 
-        $commentTable->addElement(array(
-            'content' => '('. $comment->getDatePosted() .')',
-            'cellArgs' => array('class' => 'admin')));
+		$commentTable->addElement(array(
+			'content'	=> '('. $comment->getDatePosted() .')',
+			'cellArgs'	=> array('class' => 'admin')));
 
-        if ($gallery->user->canWriteToAlbum($gallery->album)) {
-            $url = doCommand('delete-comment',
-            array('index'=> $index,
-                'comment_index' => $nr,
-                'albumName' => $albumName)
-            );
+		if ($gallery->user->canWriteToAlbum($gallery->album)) {
+			$url = doCommand('delete-comment', array(
+								'index'		=> $index,
+								'comment_index'	=> $nr,
+								'albumName'	=> $albumName)
+			);
 
-            $commentTable->addElement(array(
-                'content' => '<a href="#" onclick="javascript:' . popup($url,1) . '">'. $delCommentText .' </a>')
-            );
-        }
+			$commentTable->addElement(array(
+				'content' => '<a href="#" onclick="javascript:' . popup($url,1) . '">'. $delCommentText .' </a>')
+			);
+		}
 
-        $commentTable->addElement(array(
-            'content' => wordwrap($comment->getCommentText(), 100, " ", 1),
-            'cellArgs' => array('colspan' => $columns, 'style' => 'padding-left:10px; border-top:1px solid black', 'class' => 'albumdesc'))
-        );
-    }
-    if ($reverse) {
-        $commentTable['elements'] = array_reverse($commentTable['elements']);
-    }
+		$commentTable->addElement(array(
+			'content'	=> wordwrap($comment->getCommentText(), 100, " ", 1),
+			'cellArgs'	=> array(
+						'colspan'	=> $columns,
+						'style'		=> 'padding-left:10px; border-top:1px solid black',
+						'class'		=> 'albumdesc'))
+		);
+	}
 
-    return $commentTable->render();
+	if ($reverse) {
+		$commentTable['elements'] = array_reverse($commentTable['elements']);
+	}
+
+	return $commentTable->render();
 }
 
 /**
@@ -491,7 +495,7 @@ function generateCaption($captionType = 1, $originalFilename, $filename) {
  * @param integer   $wmAlignX
  * @param integer   $wmAlignY
  * @param integer   $wmSelect
- * @return string                       Empty on succes, otherwise an errormessage.
+ * @return string                       Empty on success, otherwise an errormessage.
  */
 function processNewImage($file, $ext, $name, $caption, $setCaption = '', $extra_fields = array(), $wmName = '', $wmAlign = 0, $wmAlignX = 0, $wmAlignY = 0, $wmSelect = 0) {
 	global $gallery;
@@ -516,12 +520,12 @@ function processNewImage($file, $ext, $name, $caption, $setCaption = '', $extra_
 		$temp_dirname	= $temp_filename . '.dir';
 
 		if (fs_is_dir($temp_dirname)) {
-			$error = gTranslate('core', "Error occurred before extracting the archive. Temporary destination exists.");
+			$error = gTranslate('core', "An error occurred before extracting the archive. Temporary destination exists.");
 			return $error;
 		}
 
 		if (! fs_mkdir($temp_dirname)) {
-			$error = gTranslate('core', "Error occurred before extracting the archive. Temporary destination could not be created.");
+			$error = gTranslate('core', "An error occurred before extracting the archive. Temporary destination could not be created.");
 			return $error;
 		}
 
@@ -533,28 +537,37 @@ function processNewImage($file, $ext, $name, $caption, $setCaption = '', $extra_
 
 		echo debugMessage(gTranslate('core', "Processing archive content."), __FILE__, __LINE__);
 		$files_to_process	= array();
-		$dir_handle			= fs_opendir($temp_dirname);
+		$dir_handle		= fs_opendir($temp_dirname);
+		$invalid_files 		= 0;
+
 		while (false !== ($content_filename = readdir($dir_handle))) {
-			if(! isXSSclean($content_filename) ||
-			   $content_filename == "." || $content_filename == '..')
-			{
+			if($content_filename == "." || $content_filename == '..') {
 				continue;
 			}
 
-			$content_file_ext		= getExtension($content_filename);
+			if(! isXSSclean($content_filename)) {
+				$invalid_files++;
+				continue;
+			}
+
+			$content_file_ext	= getExtension($content_filename);
 			$fullpath_content_file	= $temp_dirname .'/' . $content_filename;
 
 			if ($content_file_ext == 'csv') {
 				$image_info = array_merge($image_info, parse_csv($fullpath_content_file, ';'));
 			}
-			elseif (isAcceptableFormat($content_file_ext) ||
-					isAcceptableArchive($content_file_ext))
+			elseif ((isAcceptableFormat($content_file_ext) || isAcceptableArchive($content_file_ext)) &&
+				!fs_is_link($fullpath_content_file))
 			{
 				$files_to_process[] = array(
 					'filename'	=> $fullpath_content_file,
 					'ext'		=> $content_file_ext
 				);
 			}
+			else {
+				$invalid_files++;
+				continue;
+			}
 		}
 
 		closedir($dir_handle);
@@ -566,10 +579,34 @@ function processNewImage($file, $ext, $name, $caption, $setCaption = '', $extra_
 			echo debugMessage(gTranslate('core', "No Metadata"), __FILE__, __LINE__);
 		}
 
+		if ($invalid_files > 0) {
+			echo gallery_warning(
+				gTranslate('core',
+					   "%d file inside the archive was invalid.",
+					   "%d files inside the archive were invalid.",
+					   $invalid_files,
+					   '',
+					   true
+			));
+		}
+
+		if(sizeof($files_to_process) == 0) {
+			echo gallery_error(gTranslate('core', "The archive contains no valid files!"));
+		}
+		else {
+			echo gallery_info(gTranslate(
+						'core',
+						"Processing %d valid file from the archive.",
+						"Processing %d valid files from the archive.",
+						sizeof($files_to_process),
+						gTranslate('core', "The archive contains no valid files!"),
+						true
+			));
+		}
+
 		/* Now process all valid files we found */
-		echo debugMessage(gTranslate('core', "Processing valid files from archive"), __FILE__, __LINE__);
 		$loop = 0;
-		foreach ($files_to_process as $current_file) {
+		foreach ($files_to_process as $nr => $current_file) {
 			$current_file_name = basename($current_file['filename']);
 			$current_file_ext  = basename($current_file['ext']);
 
@@ -577,7 +614,7 @@ function processNewImage($file, $ext, $name, $caption, $setCaption = '', $extra_
 			$extra_fields = array();
 			if(! empty($image_info)) {
 				/* Find in meta data array */
-				$firstRow		= 1;
+				$firstRow	= 1;
 				$fileNameKey	= 'File Name';
 
 				/* $captionMetaFields will store the names (in order of priority to set caption to) */
@@ -607,6 +644,11 @@ function processNewImage($file, $ext, $name, $caption, $setCaption = '', $extra_
 				}
 			}
 
+			echo debugMessage(
+				sprintf(gTranslate('core', "Processing file #%d from archive. (Calling processNewImage)"), $nr +1),
+				__FILE__,
+				__LINE__
+			);
 			processNewImage($current_file['filename'],
 							$current_file_ext,
 							$current_file_name,
@@ -624,9 +666,9 @@ function processNewImage($file, $ext, $name, $caption, $setCaption = '', $extra_
 		echo debugMessage(gTranslate('core', "Start processing single file (image/movie not archive)."), __FILE__, __LINE__);
 
 		if (isAcceptableFormat($ext)) {
-			echo debugMessage(gTranslate('core', "Extension is accepted."), __FILE__, __LINE__, 3);
+			echo debugMessage(gTranslate('core', "Extension is accepted."), __FILE__, __LINE__, 1);
 
-			echo debugMessage(gTranslate('core', "Filename processing."), __FILE__, __LINE__,3);
+			echo debugMessage(gTranslate('core', "Filename processing."), __FILE__, __LINE__, 2);
 
 			/* Remove %20 and the like from name */
 			$name = urldecode($name);
@@ -725,4 +767,5 @@ function processNewImage($file, $ext, $name, $caption, $setCaption = '', $extra_
 
 	return $error;
 }
+
 ?>
