@@ -17,8 +17,8 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street - Fifth Floor, Boston, MA  02110-1301, USA.
  *
- * $Id: lang.php 193 2008-07-15 22:02:33Z jens $
-*/
+ * $Id: lang.php 17982 2008-09-09 21:24:10Z JensT $
+ */
 
 /**
  * @package	Language
@@ -400,11 +400,11 @@ function initLanguage($sendHeader = true) {
 	/* Check defaults */
 	$checklist = array('direction', 'charset') ;
 
-	/**
-     * This checks wether the previously defined values are available.
-     * All available values are in $nls
-     * If they are not defined we used the defaults from nls.php
-     */
+	/*
+	 * This checks wether the previously defined values are available.
+	 * All available values are in $nls
+	 * If they are not defined we used the defaults from nls.php
+	 */
 	foreach($checklist as $check) {
 		/* if no ... is given, use default*/
 		if ( !isset($nls[$check][$gallery->language])) {
@@ -425,23 +425,31 @@ function initLanguage($sendHeader = true) {
 	/* This line was added in 1.5-cvs-b190 to fix problems on FreeBSD 4.10*/
 	putenv("LC_ALL=". $gallery->language);
 
-	/* Set Locale*/
-	setlocale(LC_ALL,$gallery->locale);
+	if($gallery->language == 'tr_TR') {
+		putenv("LC_CTYPE=C");
+	}
 
-	/**
-     * Set Charset header
-     * We do this only if we are not embedded and the "user" wants it.
-     * Because headers might be sent already.
-     */
+	/* Set Locale*/
+	setlocale(LC_ALL, $gallery->locale);
+
+	if($gallery->language == 'tr_TR') {
+		setlocale(LC_CTYPE, 'C');
+	}
+
+	/*
+	 * Set Charset header
+	 * We do this only if we are not embedded and the "user" wants it.
+	 * Because headers might be sent already.
+	 */
 	if (!headers_sent() && ($sendHeader == true  || ! isset($GALLERY_EMBEDDED_INSIDE))) {
 		header('Content-Type: text/html; charset=' . $gallery->charset);
 	}
 
-	/**
-     * Test if we're using gettext.
-     * if yes, do some gettext settings.
-     * if not emulate _() function or ngettext()
-     */
+	/*
+	 * Test if we're using gettext.
+	 * if yes, do some gettext settings.
+	 * if not emulate _() function or ngettext()
+	 */
 
 	if (gettext_installed()) {
 		bindtextdomain($gallery->language. "-gallery_". where_i_am(), dirname(dirname(__FILE__)) . '/locale');
@@ -490,9 +498,9 @@ function emulate_ngettext($languages_initialized = false) {
 			// We trim the String to get rid of cr/lf
 			$value = trim($value);
 			if (stristr($value, "msgid") &&
-			! stristr($lines[$key-1],"fuzzy") && !stristr($value,"msgid_plural")) {
-				//  echo "\n<br>---SID". $value;
-				//  echo "\n<br>---PID". $lines[$key+1];
+				! stristr($lines[$key-1],"fuzzy") && !stristr($value,"msgid_plural")) {
+//				echo "\n<br>---SID". $value;
+//				echo "\n<br>---PID". $lines[$key+1];
 				if (stristr($lines[$key+1],"msgid_plural")) {
 					$singular_key=substr($value, 7,-1);
 					$translation[$singular_key]=substr(trim($lines[$key+2]),11,-1);
@@ -687,41 +695,35 @@ function i18n($buf) {
 
 function isSupportedCharset($charset) {
 	$supportedCharsets = array(
-	  'UTF-8',
-	  'ISO-8859-1',
-	  'ISO-8859-15',
-	  'cp1252',
-	  'BIG5',
-	  'GB2312',
-	  'BIG5-HKSCS',
-	  'Shift_JIS',
-	  'EUC-JP'
+		'UTF-8',
+		'ISO-8859-1',
+		'ISO-8859-15',
+		'cp1252',
+		'BIG5',
+		'GB2312',
+		'BIG5-HKSCS',
+		'Shift_JIS',
+		'EUC-JP'
 	);
 
 	$supportedCharsetsNewerPHP = array(
-	  'cp866',
-	  'cp1251',
-	  'KOI8-R'
+		'cp866',
+		'cp1251',
+		'KOI8-R'
 	);
 
 	/**
-	 * Check if we are using PHP >= 4.1.0
-	 * If yes, we can use 3rd Parameter so e.g. titles in chinese BIG5 or UTF8 are displayed correct.
+	 * Minimum PHP for Gallery 1.5.x is PHP >= 4.1.0
+	 * So we can use 3rd Parameter so e.g. titles in chinese BIG5 or UTF8 are displayed correct.
 	 * Otherwise they are messed.
 	 * Not all Gallery Charsets are supported by PHP, so only thoselisted are recognized.
 	 */
-	if (function_exists('version_compare')) {
-		if ( (version_compare(phpversion(), "4.1.0", ">=") && in_array($charset, $supportedCharsets)) ||
-			 (version_compare(phpversion(), "4.3.2", ">=") && in_array($charset, $supportedCharsetsNewerPHP)) ) {
+	if (in_array($charset, $supportedCharsets) ||
+	    (version_compare(phpversion(), "4.3.2", ">=") && in_array($charset, $supportedCharsetsNewerPHP)) ) {
 			return true;
-		}
-		else {
-			/* Unsupported Charset*/
-			return false;
-		}
 	}
 	else {
-		/* PHP too old*/
+		/* Unsupported Charset*/
 		return false;
 	}
 }
@@ -745,8 +747,8 @@ function automaticFieldsList() {
  */
 function translateableFields() {
 	return array(
-		'title'			=> gTranslate('common', "title"),
-		'Title'			=> gTranslate('common', "Title"),
+		'title'		=> gTranslate('common', "title"),
+		'Title'		=> gTranslate('common', "Title"),
 		'Description'	=> gTranslate('common', "Description"),
 		'description'	=> gTranslate('common', "description"),
         'AltText'		=> gTranslate('common', "Alt text / Tooltip"),
@@ -825,8 +827,8 @@ function languageSelector() {
 				}
 				else {
 					$langSelectTable->addElement(array(
-					'content' => $flagImage,
-					'cellArgs' => array('style' => 'padding-bottom:10px')
+						'content' => $flagImage,
+						'cellArgs' => array('style' => 'padding-bottom:10px')
 					));
 				}
 			}
@@ -834,11 +836,11 @@ function languageSelector() {
 
 		if($gallery->app->show_flags !='yes') {
 			$content = drawSelect('newlang',
-				$options,
-				$nls['language'][$gallery->language],
-				1,
-				array('style' => 'font-size:8pt;', 'onChange' => 'ML_reload()'),
-				true
+					$options,
+					$nls['language'][$gallery->language],
+					1,
+					array('style' => 'font-size:8pt;', 'onChange' => 'ML_reload()'),
+					true
 			);
 
 			$langSelectTable->addElement(array('content' => $content));
