@@ -17,7 +17,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street - Fifth Floor, Boston, MA  02110-1301, USA.
  *
- * $Id: setup.php 245 2008-07-28 11:51:39Z jens $
+ * $Id: setup.php 17982 2008-09-09 21:24:10Z JensT $
  */
 
 function evenOdd_row($fields) {
@@ -133,12 +133,14 @@ function form_password($key, $arr) {
 		$arr['value'] = array($arr['value'], $arr['value'], $arr['value'], $arr['value']);
 	}
 
-	return "<input type=\"password\" name=\"${key}[0]\" value=\"{$arr['value'][0]}\" $attrs> "
+	$html = gInput('password', $key . '[0]', null, false, $arr['value'][0], array('addCheck' => true))
 		. '<br>'
 		. "<input type=\"password\" name=\"${key}[1]\" value=\"{$arr['value'][1]}\" $attrs> "
 		. gTranslate('common', "Please retype your password here")
 		. "\n<input type=\"hidden\" name=\"${key}[2]\" value=\"{$arr['value'][2]}\">"
 		. "\n<input type=\"hidden\" name=\"${key}[3]\" value=\"{$arr['value'][3]}\">";
+
+	return $html;
 }
 
 function form_nv_pairs($key, $arr) {
@@ -175,10 +177,9 @@ function form_nv_pairs($key, $arr) {
 }
 
 function form_choice($key, $arr) {
-    $attrs  = !empty($arr['attrs']) ? $arr['attrs'] : array();
-
-    return drawSelect($key, $arr["choices"], $arr["value"], 1, $attrs, true);
+	$attrs  = !empty($arr['attrs']) ? $arr['attrs'] : array();
 
+	return drawSelect($key, $arr["choices"], $arr["value"], 1, $attrs, true);
 }
 
 function form_multiple_choice($key, $arr) {
@@ -987,30 +988,35 @@ function check_locale() {
 	// Set locale correct back
 	if (isset($gallery->locale)) {
 		setlocale(LC_ALL,$gallery->locale);
-	} else {
-		setlocale(LC_ALL,"");
+	}
+	else {
+		setlocale(LC_ALL, '');
 	}
 
-	/* DAMN, there are no suitable locales, we use Linux and our PHP uses gettext*/
-	if( sizeof($available_locales) == 0 && sizeof($maybe_locales) == 0 && getOS() == OS_LINUX && gettext_installed()) {
+	/* DAMN, there are no suitable locales, we use Linux but our PHP uses gettext */
+	if(sizeof($available_locales) == 0 &&
+	   sizeof($maybe_locales) == 0 &&
+	   getOS() == OS_LINUX &&
+	   gettext_installed())
+	{
 		return NULL;
 	}
 
 	return array(
-		'available_locales'   => $available_locales,
-		'maybe_locales'		  => $maybe_locales,
-		'unavailable_locales' => $unavailable_locales
+		'available_locales'	=> $available_locales,
+		'maybe_locales'		=> $maybe_locales,
+		'unavailable_locales'	=> $unavailable_locales
 	);
 }
 
 function config_maybe_locales() {
-	global $locale_check, $locales;
+	global $gallery, $locale_check, $locales;
 
-	$results = array();
-	$locales = $locale_check;
-	$available = $locales["available_locales"];
-	$maybe = $locales["maybe_locales"];
-	$unavailable = $locales["unavailable_locales"];
+	$results	= array();
+	$locales	= $locale_check;
+	$available	= $locales["available_locales"];
+	$maybe		= $locales["maybe_locales"];
+	$unavailable	= $locales["unavailable_locales"];
 
 	// If we are in Linux, our PHP has gettext,
 	// but we could not find any locale we skip the whole aliasing part.
@@ -1062,11 +1068,20 @@ function config_maybe_locales() {
 			$choices[$value] = $value;
 		}
 
+		$selected = '';
 		if (getOS() != OS_WINDOWS) {
 			$choices[''] = gTranslate('common', "System locale");
 			next($choices);
+
+			if(!empty($gallery->app->locale_alias[$key])) {
+				$selected = $gallery->app->locale_alias[$key];
+			}
+			else {
+				$selected = key($choices);
+			}
 		}
 
+
 		$results["locale_alias['$key']"] = array (
 			'prompt' => $nr . '.) ' . $nls['language'][$key],
 			'optional' => true,
@@ -1074,7 +1089,7 @@ function config_maybe_locales() {
 			'key' => $key,
 			'type' => 'block_element',
 			'choices' => $choices,
-			'value' => (getOS() != OS_WINDOWS) ? key($choices) : '',
+			'value' => $selected,
 			'allow_empty' => true,
 			'remove_empty' => true
 		);
@@ -1189,7 +1204,8 @@ function check_safe_mode() {
 	if (empty($safe_mode) ||
 	    !strcasecmp($safe_mode, "off") ||
 	    !strcasecmp($safe_mode, "0") ||
-	    !strcasecmp($safe_mode, "false")) {
+	    !strcasecmp($safe_mode, "false"))
+	{
 		$success[] = gTranslate('common', "safe_mode is off.");
 	}
 	else {
@@ -1343,23 +1359,23 @@ function test_write_to_dir($dir) {
 }
 
 function inOpenBasedir($dir) {
-    $openBasedir = ini_get('open_basedir');
-    if (empty($openBasedir)) {
-        return true;
-    }
+	$openBasedir = ini_get('open_basedir');
+	if (empty($openBasedir)) {
+		return true;
+	}
 
-    /*
-    * XXX: this is not perfect.  For example, if the open_basedir list
-    * contains "/usr/localx" this code will match "/usr/local".  Let's not
-    * worry too much about that now.
-    */
-    foreach (explode(':', $openBasedir) as $basedir) {
-        if (!strncmp($basedir, $dir, strlen($basedir))) {
-            return true;
-        }
-    }
+	/*
+	* XXX: this is not perfect.  For example, if the open_basedir list
+	* contains "/usr/localx" this code will match "/usr/local".  Let's not
+	* worry too much about that now.
+	*/
+	foreach (explode(':', $openBasedir) as $basedir) {
+		if (!strncmp($basedir, $dir, strlen($basedir))) {
+			return true;
+		}
+	}
 
-    return false;
+	return false;
 }
 
 function make_separator($key, $arr)  {
@@ -1503,8 +1519,9 @@ function verify_email($emailMaster) {
 	}
 
 	if (!empty($emailGreeting) &&
-		!strstr($gallery->session->configForm->emailGreeting, "!!PASSWORD!!" ) &&
-		!strstr($gallery->session->configForm->emailGreeting, "!!NEWPASSWORDLINK!!" )) {
+	    !strstr($gallery->session->configForm->emailGreeting, "!!PASSWORD!!" ) &&
+	    !strstr($gallery->session->configForm->emailGreeting, "!!NEWPASSWORDLINK!!" ))
+	{
 	       	$fail[]= sprintf(gTranslate('common', "You must include %s or %s in your welcome email."),
 				"<b>!!PASSWORD!!</b>",
 				"<b>!!NEWPASSWORDLINK!!</b>");
