@@ -50,7 +50,7 @@
  * Copyright (C) 2004 Jeremy Gilliat with rating contribution by Haplo
  * based on Bharat Mediratta's standard Gallery code.
  *
- * $Id: stats.php 284 2008-08-03 19:58:48Z jens $
+ * $Id: stats.php 17899 2008-08-23 13:31:09Z JensT $
  */
 
 require_once(dirname(__FILE__) . '/init.php');
@@ -150,6 +150,7 @@ common_header() ;
    <body dir="<?php echo $gallery->direction ?>">
 <?php
 }
+
 /* End of HTML begin, lets do some calculations etc. */
 
 $set_albumListPage = intval($set_albumListPage);
@@ -578,6 +579,7 @@ else {
 }
 
 // <!-- stats.header begin -->
+
 includeHtmlWrap("stats.header");
 
 $navigator["fullWidth"] = 100;
@@ -598,10 +600,10 @@ if (isset($album)) {
 }
 else {
 	if ($type == "comments" ) {
-        $adminText .= sprintf(gTranslate('core', "%d items with comments in this Gallery."), count($arrPhotos));
+        	$adminText .= sprintf(gTranslate('core', "%d items with comments in this Gallery."), count($arrPhotos));
 	}
 	else {
-        $adminText .= sprintf(gTranslate('core', "%d items this Gallery."), count($arrPhotos));
+        	$adminText .= sprintf(gTranslate('core', "%d items this Gallery."), count($arrPhotos));
 	}
 }
 
@@ -775,7 +777,7 @@ if ($navigator["maxPages"] > 1) {
 includeLayout('navtableend.inc');
 
 echo languageSelector();
-includeHtmlWrap("stats.footer");
+includeHtmlWrap("general.footer");
 
 if (!$GALLERY_EMBEDDED_INSIDE) { ?>
 </body>
