@@ -17,7 +17,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street - Fifth Floor, Boston, MA  02110-1301, USA.
  *
- * $Id: util.php 242 2008-07-28 10:01:41Z jens $
+ * $Id: util.php 17985 2008-09-13 20:09:04Z JensT $
  */
 
 /**
@@ -582,15 +582,21 @@ function getItemCaptureDate($file, $exifData = array()) {
 
 		switch($exifSupported) {
 			case 'exiftags':
-				if (isset($exifData['Image Created'])) {
+				if (isset($exifData['Image Generated'])) {
+					$tempDate = split(" ", $exifData['Image Generated'], 2);
+				}
+				elseif (isset($exifData['Image Created'])) {
 					$tempDate = split(" ", $exifData['Image Created'], 2);
 				}
-				break;
+
+			break;
+
 			case 'jhead':
 				if (isset($exifData['Date/Time'])) {
 					$tempDate = split(" ", $exifData['Date/Time'], 2);
 				}
-				break;
+
+			break;
 		}
 
 		if (!empty($tempDate)) {
@@ -659,6 +665,18 @@ function padded_range_array($start, $end) {
 	return $arr;
 }
 
+/**
+ * This function left in place to support patches that use it, but please use
+ * lastCommentDate functions in classes Album and AlbumItem.
+ */
+function mostRecentComment($album, $i) {
+	$id = $album->getPhotoId($i);
+	$index = $album->getPhotoIndex($id);
+	$recentcomment = $album->getComment($index, $album->numComments($i));
+
+	return $recentcomment->getDatePosted();
+}
+
 function ordinal($num = 1) {
 	$ords = array("th","st","nd","rd");
 	$val = $num;
@@ -851,8 +869,8 @@ function getOS () {
 function generate_password($len = 10) {
 	$result = '';
 	$alpha  = 'abcdefghijklmnopqrstuvwxyz' .
-			  '0123456789' .
-			  'ABCDEFGHIJKLMNOPQRSTUVWXYZ';
+		  '0123456789' .
+		  'ABCDEFGHIJKLMNOPQRSTUVWXYZ';
 
 	$size = strlen($alpha) - 1;
 	$used = array();
@@ -911,93 +929,6 @@ function logMessage ($msg, $logfile) {
 	}
 }
 
-/* simplify condition tests */
-function testRequirement($test) {
-	global $gallery;
-	if(substr($test, 0,1 ) == "!") {
-		$test = substr($test, 1);
-		$negativeTest = true;
-	}
-	else {
-		$negativeTest = false;
-	}
-
-	switch ($test) {
-		case 'albumIsRoot':
-			$result = $gallery->album->isRoot();
-			break;
-		case 'isAdminOrAlbumOwner':
-			$result = $gallery->user->isAdmin() || $gallery->user->isOwnerOfAlbum($gallery->album);
-			break;
-
-		case 'comments_enabled':
-			$result = $gallery->app->comments_enabled == 'yes';
-			break;
-
-		case 'allowComments':
-			$result = $gallery->album->fields["perms"]['canAddComments'];
-			break;
-
-		case 'hasComments':
-			$result = ($gallery->album->lastCommentDate("no") != -1);
-			break;
-
-		case 'canAddToAlbum':
-			$result = $gallery->user->canAddToAlbum($gallery->album);
-			break;
-
-		case 'canDeleteAlbum':
-			$result = $gallery->user->canDeleteAlbum($gallery->album);
-			break;
-
-		case 'extraFieldsExist':
-			$extraFields = $gallery->album->getExtraFields();
-			$result = !empty($extraFields);
-			break;
-
-		case 'isAlbumOwner':
-			$result = $gallery->user->isOwnerOfAlbum($gallery->album);
-			break;
-
-		case 'canCreateSubAlbum':
-			$result = $gallery->user->canCreateSubAlbum($gallery->album);
-			break;
-
-		case 'notOffline':
-			$result = !$gallery->session->offline;
-			break;
-
-		case 'canChangeText':
-			$result = $gallery->user->canChangeTextOfAlbum($gallery->album);
-			break;
-
-		case 'canWriteToAlbum':
-			$result = $gallery->user->canWriteToAlbum($gallery->album);
-			break;
-
-		case 'photosExist':
-			$result = $gallery->album->numPhotos(true);
-			break;
-
-		case 'watermarkingEnabled':
-			$result = isset($gallery->app->watermarkDir);
-			break;
-
-		case 'exif':
-			$result = (getExifDisplayTool() !== false);
-			break;
-
-		default:
-			$result = false;
-			break;
-	}
-	if ($negativeTest) {
-		$result = ! $result;
-	}
-
-	return $result;
-}
-
 /**
  * @return string	$location	Location where Gallery assmes the user. Can be 'core' or 'config'
  * @author Jens Tkotz
@@ -1031,7 +962,8 @@ function getSVNRevision($file) {
 	$contents = file($path);
 	foreach ($contents as $line) {
 		if (ereg("\\\x24\x49\x64: [A-Za-z_.0-9-]* ([0-9]*) .*\x24$", trim($line), $matches) ||
-			ereg("\\\x24\x49\x64: [A-Za-z_.0-9-]* ([0-9]*) .*\x24 ", trim($line), $matches)) {
+		    ereg("\\\x24\x49\x64: [A-Za-z_.0-9-]* ([0-9]*) .*\x24 ", trim($line), $matches))
+		{
 			if ($matches[1]) {
 				return $matches[1];
 			}
@@ -1079,17 +1011,6 @@ function compareVersions($old_str, $new_str) {
 	return 1;
 }
 
-function contextHelp ($link) {
-	global $gallery;
-
-	if ($gallery->app->showContextHelp == 'yes') {
-		return popup_link ('?', 'docs/context-help/' . $link, false, true, 500, 500);
-	}
-	else {
-		return null;
-	}
-}
-
 /**
  * This function strips slashes from an array Key
  * e.g. $foo[\'bar\'] will become $foo['bar']
@@ -1256,7 +1177,7 @@ function getMimeType($filename) {
 	}
 
 	$extension = getExtension($filename);
-	$mimetype = $mime_extension_map[$extension];
+	$mimetype  = $mime_extension_map[$extension];
 
 	echo debugMessage(sprintf(gTranslate('core', "MIMEtype of file %s is %s"), basename($filename), $mimetype), __FILE__, __LINE__, 2);
 	return $mimetype;
@@ -1415,7 +1336,7 @@ function array_sort_by_fields(&$data, $sortby, $order = 'asc', $caseSensitive =
 		$sort_func = $sort_funcs[$sortby];
 	}
 
-	debugMessage($code, __FILE__, __LINE__, 3);
+	debugMessage($code, __FILE__, __LINE__, 4);
 
 	if($keepIndexes) {
 		uasort($data, $sort_func);
@@ -1448,8 +1369,10 @@ function createTempAlbum($albumItemNames = array(), $dir = '') {
 
 	if(! fs_mkdir($dir)) {
 		echo gallery_error(
-          sprintf(gTranslate('core', "Gallery was unable to create a temporary subfolder in your tempdir. Please check permissions of this dir: %s"),
-		  $gallery->app->tmpDir));
+		  sprintf(gTranslate('core', "Gallery was unable to create a temporary subfolder in your tempdir. Please check permissions of this dir: %s"),
+		  $gallery->app->tmpDir)
+		);
+
 		return false;
 	}
 
@@ -1538,7 +1461,7 @@ function array_flaten($array) {
 }
 
 /**
- * This function returns the Gallery Title as a string thats save to show in <title>...</title>
+ * This function returns the Gallery Title as a string that's safe to show in <title>...</title>
  *
  * @param string $topic	 optional
  * @return string $ret
@@ -1564,5 +1487,6 @@ require_once(dirname(__FILE__) . '/lib/imageManipulation.php');
 require_once(dirname(__FILE__) . '/lib/mail.php');
 require_once(dirname(__FILE__) . '/lib/filesystem.php');
 require_once(dirname(__FILE__) . '/lib/text.php');
+require_once(dirname(__FILE__) . '/lib/progressbar.php');
 
 ?>
