@@ -17,10 +17,11 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street - Fifth Floor, Boston, MA  02110-1301, USA.
  *
- * $Id: view_album.php 259 2008-08-03 14:35:50Z jens $
+ * $Id: view_album.php 17941 2008-08-28 00:33:27Z jenst $
 */
 
 require_once(dirname(__FILE__) . '/init.php');
+require_once(dirname(__FILE__) . '/classes/Colors.php');
 
 list($page, $votes, $Vote) = getRequestVar(array('page', 'votes', 'Vote'));
 
@@ -52,8 +53,9 @@ else {
 $albumName = $gallery->session->albumName;
 
 $noCount = getRequestVar('noCount');
-if ($noCount != 1 && !isset($gallery->session->viewedAlbum[$albumName]) &&
-	!$gallery->session->offline)
+if ($noCount != 1 &&
+    !isset($gallery->session->viewedAlbum[$albumName]) &&
+    !$gallery->session->offline)
 {
 	$gallery->session->viewedAlbum[$albumName] = 1;
 	$gallery->album->incrementClicks();
@@ -94,7 +96,7 @@ if (!empty($Vote) && canVote()) {
 		for ($index = $start; $index < $start+$perPage; $index ++) {
 			$id = $gallery->album->getPhotoId($index);
 			if (!$votes[$id]) {
-				$votes[$id]=null;
+				$votes[$id] = null;
 			}
 		}
 	}
@@ -105,14 +107,14 @@ $bordercolor = $gallery->album->fields['bordercolor'];
 
 $imageCellWidth = floor(100 / $cols) . '%';
 
-$navigator['page'] = $page;
-$navigator['pageVar'] = 'page';
-$navigator['maxPages'] = $maxPages;
-$navigator['fullWidth'] = '100';
-$navigator['widthUnits'] = '%';
-$navigator['url'] = makeAlbumUrl($gallery->session->albumName);
-$navigator['spread'] = 5;
-$navigator['bordercolor'] = $bordercolor;
+$navigator['page']		= $page;
+$navigator['pageVar']		= 'page';
+$navigator['maxPages']		= $maxPages;
+$navigator['fullWidth']		= '100';
+$navigator['widthUnits']	= '%';
+$navigator['url']		= makeAlbumUrl($gallery->session->albumName);
+$navigator['spread']		= 5;
+$navigator['bordercolor']	= $bordercolor;
 
 $fullWidth = $navigator['fullWidth'] . $navigator['widthUnits'];
 
@@ -142,11 +144,11 @@ if (!$GALLERY_EMBEDDED_INSIDE) {
   	echo "<link rel=\"alternate\" title=\"$rssTitle\" href=\"$rssHref\" type=\"application/rss+xml\">";
   }
   /* prefetching/navigation */
-  $firstUrl  = makeAlbumUrl($gallery->session->albumName, '', array('page' => 1, 'noCount' => 1));
-  $prevUrl   = makeAlbumUrl($gallery->session->albumName, '', array('page' => $previousPage, 'noCount' => 1));
-  $nextUrl   = makeAlbumUrl($gallery->session->albumName, '', array('page' => $nextPage, 'noCount' => 1));
-  $lastUrl   = makeAlbumUrl($gallery->session->albumName, '', array('page' => $maxPages, 'noCount' => 1));
-  $upUrl	 = makeAlbumUrl($gallery->album->fields['parentAlbumName'], '', array('page' => $maxPages, 'noCount' => 1));
+  $firstUrl	= makeAlbumUrl($gallery->session->albumName, '', array('page' => 1, 'noCount' => 1));
+  $prevUrl	= makeAlbumUrl($gallery->session->albumName, '', array('page' => $previousPage, 'noCount' => 1));
+  $nextUrl	= makeAlbumUrl($gallery->session->albumName, '', array('page' => $nextPage, 'noCount' => 1));
+  $lastUrl	= makeAlbumUrl($gallery->session->albumName, '', array('page' => $maxPages, 'noCount' => 1));
+  $upUrl	= makeAlbumUrl($gallery->album->fields['parentAlbumName'], '', array('page' => $maxPages, 'noCount' => 1));
 
   if (!isset($first)) { ?>
   <link rel="first" href="<?php echo $firstUrl; ?>" >
@@ -156,8 +158,7 @@ if (!$GALLERY_EMBEDDED_INSIDE) {
   <link rel="next" href="<?php echo $nextUrl; ?>" >
   <link rel="last" href="<?php echo $lastUrl; ?>" >
 <?php } if ($gallery->album->isRoot() &&
-(!$gallery->session->offline ||
-	 isset($gallery->session->offlineAlbums["albums.php"]))) { ?>
+	    (!$gallery->session->offline || isset($gallery->session->offlineAlbums["albums.php"]))) { ?>
   <link rel="up" href="<?php echo makeAlbumUrl(); ?>" >
 <?php
 	 } else if (!$gallery->session->offline ||
@@ -177,25 +178,27 @@ if (!empty($gallery->album->fields["linkcolor"]) ||
   <style type="text/css">
 <?php
 // the link colors have to be done here to override the style sheet
-if ($gallery->album->fields["linkcolor"]) {
+	if ($gallery->album->fields["linkcolor"]) {
 	?>
-	A:link, A:visited, A:active
-	  { color: <?php echo $gallery->album->fields['linkcolor'] ?>; }
-	A:hover
-	  { color: #ff6600; }
+	a:link, a:visited, a:active { color: <?php echo $gallery->album->fields['linkcolor'] ?>; }
+	a:hover { color: #ff6600; }
 <?php
-}
-if ($gallery->album->fields["bgcolor"]) {
-	echo "BODY { background-color:".$gallery->album->fields['bgcolor']."; }";
-}
-if (isset($gallery->album->fields['background']) && $gallery->album->fields['background']) {
-	echo "BODY { background-image:url(".$gallery->album->fields['background']."); } ";
-}
-if ($gallery->album->fields["textcolor"]) {
-	echo "BODY, TD {color:".$gallery->album->fields['textcolor']."; }";
-	echo ".head {color:".$gallery->album->fields['textcolor']."; }";
-	echo ".headbox {background-color:".$gallery->album->fields['bgcolor']."; }";
-}
+	}
+
+	if ($gallery->album->fields["bgcolor"]) {
+		$bgcolor = new RGBColor($gallery->album->fields['bgcolor']);
+		echo "body { background-color:".$gallery->album->fields['bgcolor']."; }";
+		echo "\n#adminbox td {background-color:". $bgcolor->getDarken() ."; }";
+	}
+
+	if (isset($gallery->album->fields['background']) && $gallery->album->fields['background']) {
+		echo "\nbody { background-image:url(".$gallery->album->fields['background']."); } ";
+	}
+
+	if ($gallery->album->fields["textcolor"]) {
+		echo "\nbody, td {color:".$gallery->album->fields['textcolor']."; }";
+		echo "\n.head {color:".$gallery->album->fields['textcolor']."; }";
+	}
 ?>
   </style>
 <?php } ?>
@@ -281,7 +284,7 @@ if (!empty($adminCommands)) {
 }
 
 if ($gallery->album->fields["slideshow_type"] != "off" &&
-($numPhotos != 0 || ($numVisibleItems != 0 && $gallery->album->fields['slideshow_recursive'] == "yes"))) {
+   ($numPhotos != 0 || ($numVisibleItems != 0 && $gallery->album->fields['slideshow_recursive'] == "yes"))) {
 	$iconText = getIconText('display.gif', gTranslate('core', "Slideshow"));
 	$iconElements[] = '<a href="'
 	. makeGalleryUrl("slideshow.php",
@@ -289,7 +292,7 @@ if ($gallery->album->fields["slideshow_type"] != "off" &&
 }
 
 /* User is allowed to view ALL comments */
-if (checkRequirements('allowComments', 'comments_enabled', 'hasComments')) {
+if (checkRequirements('comments_enabled', 'hasComments', 'comments_overview_for_all')) {
 	$iconElements[] = galleryLink(
 		makeGalleryUrl("view_comments.php", array("set_albumName" => $gallery->session->albumName)),
 		gTranslate('core', "View&nbsp;comments"),
@@ -414,8 +417,10 @@ if ($gallery->album->getPollShowResults()) {
    </script>
 <?php
 
-echo makeFormIntro('view_album.php',
-array('name' => 'vote_form', 'style' => 'margin-bottom: 0px;'));
+echo makeFormIntro(
+	'view_album.php',
+	array('name' => 'vote_form', 'style' => 'margin-bottom: 0px;')
+);
 
 if (canVote()) {
 	$nv_pairs = $gallery->album->getVoteNVPairs();
@@ -592,7 +597,7 @@ if ($numPhotos) {
 			echo "<div style=\"width: {$divCellWidth}px;\"  align=\"center\" class=\"vafloat\">\n";
 			/* Do the clickable-dimensions row */
 			if (!strcmp($gallery->album->fields['showDimensions'], 'yes')) {
-				echo '<span class="dim">';
+				echo '<span class="dim fineprint">';
 				$photo	= $gallery->album->getPhoto($i);
 				$image	= $photo->image;
 				if (!empty($image) && !$photo->isMovie()) {
@@ -667,7 +672,7 @@ if ($numPhotos) {
 				$buf = '';
 				$link = '';
 				if ($gallery->user->canDownloadAlbum($myAlbum) && $myAlbum->numPhotos(1)) {
-					$iconText = getIconText('compressed.png', gTranslate('core', "Download entire album as archive"), 'yes');
+					$iconText = getIconText('compressed.gif', gTranslate('core', "Download entire album as archive"), 'yes');
 					$link = popup_link($iconText, 'download.php?set_albumName='. $gallery->album->getAlbumName($i),false,false,550, 600, '', '', '', false);
 				}
 
@@ -745,14 +750,49 @@ if ($numPhotos) {
 				$form_pos++;
 			}
 
-			$albumItemOptions = getItemActions($i, false, true, true);
-			if (sizeof($albumItemOptions) > 2 ||
-				(sizeof($albumItemOptions) == 2 && !isset($albumItemOptions['showExif'])))
-			{
-				echo drawSelect2("s$i", $albumItemOptions, array(
-										'onChange' => "imageEditChoice(document.vote_form.s$i)",
-										'class' => 'adminform'));
+			$albumItemOptions = getItemActions($i, true, true, true);
+
+			if (sizeof($albumItemOptions) > 3) {
+				echo drawSelect2(
+					"s$i",
+					$albumItemOptions,
+					array(
+						'onChange' => "jopen(this)",
+						'class' => 'g-admin')
+				);
 			}
+			/*
+			 * uncomment this part if you want tiny icons
+			 * for photo properties and ecards in the thumbs view.
+			else {
+				$specialIconMode = "yes";
+				$optionsHTML = '';
+
+				// Show item options. Such as eCard or photo properties link.
+				foreach ($albumItemOptions as $key => $option) {
+					if (!isset($option['separate'])) continue;
+
+					if(!empty($option['value'])) {
+						if (stristr($option['value'], 'popup')) {
+							$content = popup_link(
+								$option['text'],
+								$option['value'],
+								true, false, 550, 600, '', '', $option['icon'], true, false
+							);
+						}
+						else {
+							$content = galleryIconLink(
+									$option['value'],
+									$option['icon'],
+									$option['text']
+							);
+						}
+						$optionsHTML .= $content . "&nbsp;\n";
+					}
+				}
+				echo $optionsHTML;
+			}
+			*/
 
 			if (canVote()) {
 				print '</div>';
